using System;
using System.Collections.Generic;
using System.Reflection;
using System.Xml;
using System.Xml.XPath;

namespace XmlObjectsDocGui.Generation
{
  /// <summary>
  /// Class to extract information from one or more XML files generated by csc /doc
  /// </summary>
  class DocInfoExtractor
  {
    /// <summary>
    /// Handles a new file. The information is stored internally, ready to be queried using the
    /// other class's methods
    /// </summary>
    /// <param name="path"></param>
    public void Handle(string path)
    {
      XPathDocument doc = new XPathDocument(path);
      XPathNavigator nav = doc.CreateNavigator();
      XPathNodeIterator nodeIter = nav.Select("*/members/member");
      while (nodeIter.MoveNext())
      {
        extracted.Add(getMember(nodeIter.Current), extractSummary(nodeIter.Current));
      };
    }

    /// <summary>
    /// Returns the summary on a given type
    /// </summary>
    /// <param name="type"></param>
    /// <returns></returns>
    public string GetTypeInfo(Type type)
    {
      string ret;
      return extracted.TryGetValue("T:" + type.FullName, out ret) ? ret : "";
    }

    /// <summary>
    /// Returns the summary on a given field
    /// </summary>
    /// <param name="field"></param>
    /// <returns></returns>
    public string GetFieldInfo(FieldInfo field)
    {
      string ret;
      return extracted.TryGetValue(String.Format("F:{0}.{1}", field.DeclaringType.FullName, field.Name), out ret) ? ret : "";
    }

    private string getMember(XPathNavigator nav)
    {
      return nav.GetAttribute("name", "");
    }

    private string extractSummary(XPathNavigator nav)
    {
      return nav.Value;
    }

    private Dictionary<string, string> extracted = new Dictionary<string, string>();
  }
}
